@@ -13,23 +13,28 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
+from __future__ import annotations
+
 import asyncio
+from functools import partial
 import logging
+from threading import Thread
 from types import TracebackType
+from typing import Any, Dict, Optional, Type, TYPE_CHECKING
+
+import google.cloud.sql.connector.asyncpg as asyncpg
+from google.cloud.sql.connector.exceptions import ConnectorLoopError
 from google.cloud.sql.connector.instance import (
     Instance,
     IPTypes,
 )
-import google.cloud.sql.connector.pymysql as pymysql
 import google.cloud.sql.connector.pg8000 as pg8000
+import google.cloud.sql.connector.pymysql as pymysql
 import google.cloud.sql.connector.pytds as pytds
-import google.cloud.sql.connector.asyncpg as asyncpg
-from google.cloud.sql.connector.utils import generate_keys, format_database_user
-from google.cloud.sql.connector.exceptions import ConnectorLoopError
-from google.auth.credentials import Credentials
-from threading import Thread
-from typing import Any, Dict, Optional, Type
-from functools import partial
+from google.cloud.sql.connector.utils import format_database_user, generate_keys
+
+if TYPE_CHECKING:
+    from google.auth.credentials import Credentials
 
 logger = logging.getLogger(name=__name__)
 
@@ -222,9 +227,7 @@ class Connector:
             raise KeyError(f"Driver '{driver}' is not supported.")
 
         ip_type = kwargs.pop("ip_type", self._ip_type)
-        timeout = kwargs.pop("timeout", self._timeout)
-        if "connect_timeout" in kwargs:
-            timeout = kwargs.pop("connect_timeout")
+        kwargs["timeout"] = kwargs.get("timeout", self._timeout)
 
         # Host and ssl options come from the certificates and metadata, so we don't
         # want the user to specify them.
@@ -232,8 +235,8 @@ class Connector:
         kwargs.pop("ssl", None)
         kwargs.pop("port", None)
 
-        # helper function to wrap in timeout
-        async def get_connection() -> Any:
+        # attempt to make connection to Cloud SQL instance
+        try:
             instance_data, ip_address = await instance.connect_info(ip_type)
 
             # format `user` param for automatic IAM database authn
@@ -256,13 +259,8 @@ class Connector:
             )
             return await self._loop.run_in_executor(None, connect_partial)
 
-        # attempt to make connection to Cloud SQL instance for given timeout
-        try:
-            return await asyncio.wait_for(get_connection(), timeout)
-        except asyncio.TimeoutError:
-            raise TimeoutError(f"Connection timed out after {timeout}s")
         except Exception:
-            # with any other exception, we attempt a force refresh, then throw the error
+            # with any exception, we attempt a force refresh, then throw the error
             instance.force_refresh()
             raise
 
