@@ -13,17 +13,19 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 """
+from __future__ import annotations
 
+import asyncio
+import copy
+import datetime
+import logging
+from typing import Any, Dict, List, TYPE_CHECKING
 
-import aiohttp
-import google.auth
 from google.auth.credentials import Credentials, Scoped
 import google.auth.transport.requests
-from typing import Any, Dict, List
-import datetime
-import copy
-import asyncio
-import logging
+
+if TYPE_CHECKING:
+    import aiohttp
 
 logger = logging.getLogger(name=__name__)
 
